@@ -61,6 +61,14 @@ class GeoJSON(dict):
                 d[str_key] = mapping[k]
             try:
                 type_ = d.pop("type")
+                try:
+                    type_ = str(type_)
+                except (UnicodeEncodeError):
+                    # If the type contains non-ascii characters, we can assume
+                    # it's not a valid GeoJSON type
+                    raise AttributeError(
+                        unicode("{0} is not a GeoJSON type").format(
+                        unicode(type_)))
                 geojson_factory = getattr(geojson.factory, type_)
                 if not issubclass(geojson_factory, GeoJSON):
                     raise TypeError("""\
